<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//zh_CN

$LANG=array();


$LANG['backup'][0]="备份为SQL"; 
$LANG['backup'][1]="备份为XML"; 
$LANG['backup'][11]="大小"; 
$LANG['backup'][13]="视图/下载"; 
$LANG['backup'][16]="是否确实使用备份文件覆盖当前数据库"; 
$LANG['backup'][17]="是否确实要删除这个文件"; 
$LANG['backup'][18]="是否确实要备份数据库"; 
$LANG['backup'][19]="现在"; 
$LANG['backup'][21]="文件已经存在"; 
$LANG['backup'][22]="无法找到该字段"; 
$LANG['backup'][23]="Mysql 错误启动从"; 
$LANG['backup'][24]="自动重定向，否则点击"; 

$LANG['bookmark'][1]="书签"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="您尚未设置任何书签"; 
$LANG['bookmark'][4]="新建书签"; 
$LANG['bookmark'][5]="公共书签"; 
$LANG['bookmark'][6]="应用为默认设置"; 

$LANG['buttons'][0]="搜索"; 
$LANG['buttons'][2]="确定"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="安装"; 
$LANG['buttons'][5]="卸载"; 
$LANG['buttons'][6]="删除"; 
$LANG['buttons'][7]="更新"; 
$LANG['buttons'][8]="添加"; 
$LANG['buttons'][9]="连接"; 
$LANG['buttons'][10]="断开"; 
$LANG['buttons'][11]="下一步"; 
$LANG['buttons'][12]="上一步"; 
$LANG['buttons'][13]="返回"; 
$LANG['buttons'][14]="更新"; 
$LANG['buttons'][15]="日程表"; 
$LANG['buttons'][16]="空白"; 
$LANG['buttons'][17]="反向选择"; 
$LANG['buttons'][18]="全选"; 
$LANG['buttons'][19]="全部取消"; 
$LANG['buttons'][20]="移动"; 
$LANG['buttons'][21]="恢复"; 
$LANG['buttons'][22]="清除"; 
$LANG['buttons'][23]="展示"; 
$LANG['buttons'][24]="向上"; 
$LANG['buttons'][25]="向下"; 
$LANG['buttons'][27]="导出当前页面为PDF文件"; 
$LANG['buttons'][28]="导出所有页面为SLK文件"; 
$LANG['buttons'][29]="导出所有页面为PDF文件"; 
$LANG['buttons'][30]="导出所有页面为SLK文件"; 
$LANG['buttons'][31]="导出"; 
$LANG['buttons'][32]="末页"; 
$LANG['buttons'][33]="开始"; 
$LANG['buttons'][34]="取消"; 
$LANG['buttons'][37]="导入"; 
$LANG['buttons'][38]="解锁"; 
$LANG['buttons'][39]="替换"; 
$LANG['buttons'][40]="显示所有"; 
$LANG['buttons'][41]="激活"; 
$LANG['buttons'][42]="无效的"; 
$LANG['buttons'][43]="浏览"; 
$LANG['buttons'][44]="导出当前页面为CSV文件"; 
$LANG['buttons'][45]="导出所有页面为CSV文件"; 
$LANG['buttons'][46]="在...之前"; 
$LANG['buttons'][47]="在....之后"; 
$LANG['buttons'][48]="传送"; 
$LANG['buttons'][49]="保护；保存"; 
$LANG['buttons'][50]="测试"; 
$LANG['buttons'][51]="保存"; 
$LANG['buttons'][52]="导入"; 
$LANG['buttons'][53]="清除"; 
$LANG['buttons'][55]="第一页"; 
$LANG['buttons'][56]="末页"; 
$LANG['buttons'][57]="执行"; 
$LANG['buttons'][58]="更新"; 
$LANG['buttons'][59]="分离"; 

$LANG['calendar'][0]="年－月－日"; 
$LANG['calendar'][1]="日－月－年"; 
$LANG['calendar'][2]="月－日－年"; 

$LANG['calendarD'][0]="一"; 
$LANG['calendarD'][1]="二"; 
$LANG['calendarD'][2]="三"; 
$LANG['calendarD'][3]="四"; 
$LANG['calendarD'][4]="五"; 
$LANG['calendarD'][5]="五"; 
$LANG['calendarD'][6]="日"; 

$LANG['calendarDay'][0]="星期天"; 
$LANG['calendarDay'][1]="星期一"; 
$LANG['calendarDay'][2]="星期二"; 
$LANG['calendarDay'][3]="星期三"; 
$LANG['calendarDay'][4]="星期四"; 
$LANG['calendarDay'][5]="星期五"; 
$LANG['calendarDay'][6]="星期六"; 

$LANG['calendarM'][0]="1月"; 
$LANG['calendarM'][1]="2月"; 
$LANG['calendarM'][2]="3月"; 
$LANG['calendarM'][3]="4月"; 
$LANG['calendarM'][4]="5月"; 
$LANG['calendarM'][5]="6月"; 
$LANG['calendarM'][6]="7月"; 
$LANG['calendarM'][7]="8月"; 
$LANG['calendarM'][8]="9月"; 
$LANG['calendarM'][9]="10月"; 
$LANG['calendarM'][10]="11月"; 
$LANG['calendarM'][11]="12月"; 

$LANG['cartridges'][0]="墨盒"; 
$LANG['cartridges'][7]="没有找到墨盒"; 
$LANG['cartridges'][9]="没有墨盒"; 
$LANG['cartridges'][10]="调色剂"; 
$LANG['cartridges'][11]="喷墨打印机"; 
$LANG['cartridges'][12]="墨盒类型"; 
$LANG['cartridges'][13]="新"; 
$LANG['cartridges'][14]="用过的"; 
$LANG['cartridges'][15]="旧的"; 
$LANG['cartridges'][16]="墨盒"; 
$LANG['cartridges'][20]="新"; 
$LANG['cartridges'][21]="用过的"; 
$LANG['cartridges'][22]="旧的"; 
$LANG['cartridges'][24]="添加日期"; 
$LANG['cartridges'][27]="在"; 
$LANG['cartridges'][29]="用完"; 
$LANG['cartridges'][32]="兼容打印机模型"; 
$LANG['cartridges'][33]="用过的墨盒"; 
$LANG['cartridges'][34]="可用墨盒？"; 
$LANG['cartridges'][35]="旧墨盒"; 
$LANG['cartridges'][37]="色带"; 
$LANG['cartridges'][39]="页计数"; 
$LANG['cartridges'][40]="平均库存时间"; 
$LANG['cartridges'][41]="平均使用时间"; 
$LANG['cartridges'][42]="平均打印页数"; 

$LANG['central'][2]="前"; 
$LANG['central'][4]="没有事件"; 
$LANG['central'][5]="主页"; 
$LANG['central'][6]="注销"; 
$LANG['central'][7]="帮助"; 
$LANG['central'][8]="添加的内容"; 
$LANG['central'][9]="您进展中的标签"; 
$LANG['central'][10]="新标签"; 
$LANG['central'][12]="个人视图"; 
$LANG['central'][13]="全局视图"; 
$LANG['central'][14]="组视图"; 
$LANG['central'][18]="关闭你的标签"; 
$LANG['central'][19]="验证你的标签"; 

$LANG['choice'][0]="否"; 
$LANG['choice'][1]="是"; 

$LANG['common'][0]="没有名称"; 
$LANG['common'][1]="项目"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="网络"; 
$LANG['common'][5]="制造商"; 
$LANG['common'][6]="模板名称"; 
$LANG['common'][7]="选项模板"; 
$LANG['common'][8]="处理模板…"; 
$LANG['common'][9]="添加一块模板…"; 
$LANG['common'][10]="技术负责任"; 
$LANG['common'][11]="受限视图"; 
$LANG['common'][12]="设定"; 
$LANG['common'][13]="模板"; 
$LANG['common'][14]="模板"; 
$LANG['common'][15]="位置"; 
$LANG['common'][16]="名称"; 
$LANG['common'][17]="类型"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="序列号"; 
$LANG['common'][20]="固定资产编号"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="模型"; 
$LANG['common'][23]="Operation successful"; 
$LANG['common'][24]="没有选项的元素或非常确定操作"; 
$LANG['common'][25]="批注"; 
$LANG['common'][26]="上次更新日期"; 
$LANG['common'][27]="日期"; 
$LANG['common'][28]="已删除"; 
$LANG['common'][29]="插件"; 
$LANG['common'][30]="添加新项目"; 
$LANG['common'][31]="空白的模板"; 
$LANG['common'][32]="特征"; 
$LANG['common'][33]="共计"; 
$LANG['common'][34]="用户"; 
$LANG['common'][35]="组"; 
$LANG['common'][36]="类别"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="复制品元素许多一次作为那里是连接"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="邮件通知"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="名字"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="最大兆"; 
$LANG['common'][46]="名片"; 
$LANG['common'][47]="进度"; 
$LANG['common'][48]="姓"; 
$LANG['common'][49]="无"; 
$LANG['common'][50]="是否确认删除？"; 
$LANG['common'][51]="全称"; 
$LANG['common'][52]="服务器"; 
$LANG['common'][53]="清单"; 
$LANG['common'][54]="未发现项"; 
$LANG['common'][55]="是否确认删除该项目？"; 
$LANG['common'][56]="标准界面"; 
$LANG['common'][57]="标题"; 
$LANG['common'][58]="最大值"; 
$LANG['common'][59]="全球"; 
$LANG['common'][60]="激活"; 
$LANG['common'][61]="未知错误"; 
$LANG['common'][62]="其他"; 
$LANG['common'][63]="错误"; 
$LANG['common'][64]="管理员"; 
$LANG['common'][65]="接口"; 
$LANG['common'][66]="全部"; 
$LANG['common'][67]="其他"; 
$LANG['common'][68]="横向"; 
$LANG['common'][69]="纵向"; 
$LANG['common'][70]="成功添加项"; 
$LANG['common'][71]="成功更新项"; 
$LANG['common'][72]="成功删除项"; 
$LANG['common'][73]="项成功删除"; 
$LANG['common'][74]="成功恢复项"; 
$LANG['common'][75]="在实体上没有权限去使这个项循环"; 
$LANG['common'][76]="公共"; 
$LANG['common'][77]="隐藏"; 
$LANG['common'][78]="设置公用的"; 
$LANG['common'][79]="设置隐私"; 
$LANG['common'][80]="读取中........."; 
$LANG['common'][81]="不显示已删除物品"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="你不允许执行此行为"; 
$LANG['common'][84]="标志更改禁止。建立连接项。"; 
$LANG['common'][85]="改变成果实体的可见性"; 
$LANG['common'][86]="你不允许在子实体上改变可见性标志"; 
$LANG['common'][87]="新建名片"; 
$LANG['common'][88]="个人的"; 
$LANG['common'][89]="未安装"; 
$LANG['common'][90]="对象"; 
$LANG['common'][91]="改变不了这一属性。它继承了其母公司。"; 
$LANG['common'][92]="替代用户名"; 
$LANG['common'][93]="新的子标题"; 

$LANG['computers'][0]="卷"; 
$LANG['computers'][1]="可用空间百分比"; 
$LANG['computers'][2]="可用空间"; 
$LANG['computers'][3]="总空间"; 
$LANG['computers'][4]="文件系统"; 
$LANG['computers'][5]="挂载点"; 
$LANG['computers'][6]="分区"; 
$LANG['computers'][7]="添加卷"; 
$LANG['computers'][8]="卷"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="操作系统序列号"; 
$LANG['computers'][11]="操作系统产品ID"; 
$LANG['computers'][14]="Inserted"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="没有连接的显示器。"; 
$LANG['computers'][38]="没有连接的打印机"; 
$LANG['computers'][39]="打印机"; 
$LANG['computers'][40]="显示器"; 
$LANG['computers'][46]="设备"; 
$LANG['computers'][47]="没有连接的设备"; 
$LANG['computers'][48]="地点已更新。与此项相关项目也同时被移动到同一个地点。"; 
$LANG['computers'][49]="用户名已更新。与此项相关物品也同时被移动到新的用户名下。"; 
$LANG['computers'][50]="用户或小组已更新。与此项相关项目也同时被移动到相应位置。"; 
$LANG['computers'][51]="更新源"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="升级包"; 
$LANG['computers'][54]="没有电话连接"; 
$LANG['computers'][55]="电话"; 
$LANG['computers'][56]="状态更新。连接的项目已被更新使用此状态"; 

$LANG['connect'][0]="直接连接"; 
$LANG['connect'][1]="未连接。"; 
$LANG['connect'][15]="自动更新下列物品"; 
$LANG['connect'][16]="注意：下列两个物品硬件不相同"; 

$LANG['consumables'][0]="消费品"; 
$LANG['consumables'][1]="在库存"; 
$LANG['consumables'][2]="引用"; 
$LANG['consumables'][7]="没有消费品发现了"; 
$LANG['consumables'][9]="没有消费品"; 
$LANG['consumables'][12]="消耗类型"; 
$LANG['consumables'][13]="新的"; 
$LANG['consumables'][15]="用过的"; 
$LANG['consumables'][16]="消费品"; 
$LANG['consumables'][20]="新的"; 
$LANG['consumables'][22]="用过的"; 
$LANG['consumables'][23]="状态"; 
$LANG['consumables'][26]="使用日期"; 
$LANG['consumables'][32]="授予"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="储蓄地点"; 
$LANG['consumables'][37]="回到目录"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="合同到期自从。。"; 
$LANG['contract'][1]="自。。。之后的合同通知"; 

$LANG['crontask'][0]="自动操作"; 
$LANG['crontask'][1]="从OCSNG同步设备"; 
$LANG['crontask'][2]="墨盒发送警报"; 
$LANG['crontask'][3]="在耗材上发送警报"; 
$LANG['crontask'][4]="在到期执照上发出警报"; 
$LANG['crontask'][5]="在合同上发出警报"; 
$LANG['crontask'][6]="财务信息发送警报"; 
$LANG['crontask'][7]="清除老的日志"; 
$LANG['crontask'][8]="数据库优化"; 
$LANG['crontask'][9]="检索电子邮件（邮件接收器）"; 
$LANG['crontask'][10]="检查MySQL的副本"; 
$LANG['crontask'][11]="检查更新"; 
$LANG['crontask'][12]="清理过期的通用任务程序"; 
$LANG['crontask'][13]="清洁生成的图形"; 
$LANG['crontask'][14]="自动标签关闭"; 
$LANG['crontask'][15]="没有解决标签"; 
$LANG['crontask'][31]="禁用"; 
$LANG['crontask'][32]="预定的"; 
$LANG['crontask'][33]="正在运行"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="运行方式"; 
$LANG['crontask'][37]="运行频率"; 
$LANG['crontask'][38]="运行周期"; 
$LANG['crontask'][39]="检索电子邮件数"; 
$LANG['crontask'][40]="最后运行的"; 
$LANG['crontask'][41]="下一个运行"; 
$LANG['crontask'][42]="尽快"; 
$LANG['crontask'][43]="不采取行动之前"; 
$LANG['crontask'][44]="操作完成，部分更新"; 
$LANG['crontask'][45]="操作完成，全部处理"; 
$LANG['crontask'][46]="操作完成，无需更新"; 
$LANG['crontask'][47]="最近运行列表"; 
$LANG['crontask'][48]="开始"; 
$LANG['crontask'][50]="运行计数"; 
$LANG['crontask'][51]="最短时间"; 
$LANG['crontask'][52]="最大时间"; 
$LANG['crontask'][53]="平均时间"; 
$LANG['crontask'][55]="最小计数"; 
$LANG['crontask'][56]="最大计数"; 
$LANG['crontask'][57]="平均计数"; 
$LANG['crontask'][58]="合计"; 
$LANG['crontask'][59]="平均速度"; 
$LANG['crontask'][60]="系统锁定"; 
$LANG['crontask'][61]="禁用插件"; 
$LANG['crontask'][62]="原理"; 

$LANG['devices'][0]="添加一个添加新部件"; 
$LANG['devices'][1]="硬盘"; 
$LANG['devices'][2]="显卡"; 
$LANG['devices'][3]="网卡"; 
$LANG['devices'][4]="处理器"; 
$LANG['devices'][5]="主板"; 
$LANG['devices'][6]="内存"; 
$LANG['devices'][7]="声卡"; 
$LANG['devices'][19]="驱动器"; 
$LANG['devices'][20]="控制器"; 
$LANG['devices'][21]="其他部件"; 
$LANG['devices'][22]="机箱"; 
$LANG['devices'][23]="电源"; 
$LANG['devices'][24]="按默认方式"; 
$LANG['devices'][25]="添加部件"; 
$LANG['devices'][26]="删除部件"; 

$LANG['device_case'][0]="大小"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="写入"; 
$LANG['device_drive'][1]="速度"; 

$LANG['device_hdd'][0]="转/每分"; 
$LANG['device_hdd'][1]="高速缓存"; 
$LANG['device_hdd'][4]="容量"; 

$LANG['device_iface'][0]="流量"; 
$LANG['device_iface'][2]="物理地址"; 

$LANG['device_moboard'][0]="芯片组"; 

$LANG['device_power'][0]="电源"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="频率"; 
$LANG['device_ram'][2]="大小"; 

$LANG['document'][1]="查验和（SHA1）"; 
$LANG['document'][2]="文件"; 
$LANG['document'][3]="标题"; 
$LANG['document'][4]="MIME类型"; 
$LANG['document'][7]="文件类型"; 
$LANG['document'][9]="扩展名"; 
$LANG['document'][10]="图标"; 
$LANG['document'][11]="允许下载"; 
$LANG['document'][15]="下载"; 
$LANG['document'][16]="添加一个文件"; 
$LANG['document'][18]="文件"; 
$LANG['document'][19]="关联的项目"; 
$LANG['document'][21]="同文件联系在一起"; 
$LANG['document'][22]="当前文件"; 
$LANG['document'][23]="文件太大不能被添加"; 
$LANG['document'][24]="文件删除成功"; 
$LANG['document'][25]="删除文件失败"; 
$LANG['document'][26]="文件有效。上载成功。"; 
$LANG['document'][27]="潜在的加载攻击。 或者文件太大。 移动临时文件失败。"; 
$LANG['document'][28]="没有文件被指定"; 
$LANG['document'][29]="创建目录失败"; 
$LANG['document'][30]="验证您有正确权限"; 
$LANG['document'][31]="目录为文件不存在"; 
$LANG['document'][32]="未经授权文件类型"; 
$LANG['document'][33]="链接"; 
$LANG['document'][34]="创建目录"; 
$LANG['document'][35]="上载目录不存在"; 
$LANG['document'][36]="使用FTP安装了文件"; 
$LANG['document'][37]="没有文件有效"; 
$LANG['document'][38]="没被发现的文件"; 
$LANG['document'][39]="文件移动成功"; 
$LANG['document'][40]="文件移动发生了故障"; 
$LANG['document'][41]="文件拷贝成功"; 
$LANG['document'][42]="添加在"; 
$LANG['document'][43]="未知的文件"; 
$LANG['document'][44]="无效文件名"; 
$LANG['document'][45]="对这个文件的越权存取"; 
$LANG['document'][46]="在发送文件时出现故障（可能是文件过大）"; 
$LANG['document'][48]="文件已存在"; 
$LANG['document'][49]="文件被改变（坏的校验）"; 
$LANG['document'][50]="附件"; 

$LANG['entity'][0]="实体"; 
$LANG['entity'][2]="根实体"; 
$LANG['entity'][3]="转到一个实体"; 
$LANG['entity'][5]="全自动电脑赋值"; 
$LANG['entity'][6]="自动用户分配"; 
$LANG['entity'][7]="树结构"; 
$LANG['entity'][8]="按实体"; 
$LANG['entity'][9]="成果实体"; 
$LANG['entity'][10]="选择所需的实体"; 
$LANG['entity'][11]="浏览实体及其分实体"; 
$LANG['entity'][12]="LDAP属性识别实体"; 
$LANG['entity'][13]="标记确定实体"; 
$LANG['entity'][14]="详细信息"; 
$LANG['entity'][15]="LDAP目录中的一个实体"; 
$LANG['entity'][16]="搜索过滤器（如果被需要）"; 
$LANG['entity'][17]="自动关闭配置"; 
$LANG['entity'][18]="自动关闭标签后"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="服务"; 
$LANG['event'][3]="级别"; 
$LANG['event'][4]="消息"; 
$LANG['event'][18]="域"; 
$LANG['event'][19]="更新"; 
$LANG['event'][20]="没有历史"; 

$LANG['financial'][1]="合同"; 
$LANG['financial'][2]="毕生的"; 
$LANG['financial'][3]="财政信息"; 
$LANG['financial'][4]="数字"; 
$LANG['financial'][5]="花费"; 
$LANG['financial'][6]="合同类型"; 
$LANG['financial'][8]="期间"; 
$LANG['financial'][9]="年"; 
$LANG['financial'][10]="通知"; 
$LANG['financial'][11]="发票周期"; 
$LANG['financial'][13]="会计数字"; 
$LANG['financial'][14]="购买日期"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="保修信息"; 
$LANG['financial'][18]="序号"; 
$LANG['financial'][19]="从。。交付"; 
$LANG['financial'][20]="钳制数字"; 
$LANG['financial'][21]="价值"; 
$LANG['financial'][22]="分期偿还类型"; 
$LANG['financial'][23]="分期偿还期间"; 
$LANG['financial'][24]="添加联系人…"; 
$LANG['financial'][25]="Add Supplier..."; 
$LANG['financial'][26]="Supplier"; 
$LANG['financial'][30]="电传"; 
$LANG['financial'][33]="添加联系人"; 
$LANG['financial'][36]="添加一个合同"; 
$LANG['financial'][42]="商务"; 
$LANG['financial'][43]="工程师"; 
$LANG['financial'][44]="地址"; 
$LANG['financial'][45]="网站"; 
$LANG['financial'][46]="同联系人联系在一起"; 
$LANG['financial'][47]="线性"; 
$LANG['financial'][48]="递减"; 
$LANG['financial'][50]="借出"; 
$LANG['financial'][51]="租赁"; 
$LANG['financial'][52]="谎话"; 
$LANG['financial'][53]="保险"; 
$LANG['financial'][54]="硬件支持"; 
$LANG['financial'][55]="软件支持"; 
$LANG['financial'][56]="服务文档了"; 
$LANG['financial'][57]="月"; 
$LANG['financial'][59]="干预小时"; 
$LANG['financial'][60]="在星期"; 
$LANG['financial'][61]="在星期六"; 
$LANG['financial'][62]="星期天和庆祝天"; 
$LANG['financial'][65]="Associated suppliers"; 
$LANG['financial'][66]="同合同联系在一起"; 
$LANG['financial'][68]="激活财政信息"; 
$LANG['financial'][69]="合同周期性"; 
$LANG['financial'][76]="开始日期"; 
$LANG['financial'][77]="分期偿还系数"; 
$LANG['financial'][78]="保修结尾价值"; 
$LANG['financial'][79]="第三方类型"; 
$LANG['financial'][80]="保修结尾"; 
$LANG['financial'][81]="会计净值"; 
$LANG['financial'][82]="发票号"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="对于此类型的元件，财政信息对于你所应该添加的原理只是一个模板。"; 
$LANG['financial'][85]="没建立的请求的项目"; 
$LANG['financial'][86]="结束合约"; 
$LANG['financial'][87]="预算"; 
$LANG['financial'][88]="到期："; 
$LANG['financial'][89]="TCO (价值+追踪费用)"; 
$LANG['financial'][90]="月度TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="从少于30天到期的合同"; 
$LANG['financial'][94]="在少于7天到期的合同"; 
$LANG['financial'][95]="在少于30天到期的合同"; 
$LANG['financial'][96]="有通知起点在少于7天的合同"; 
$LANG['financial'][97]="有通知起点在少于30天的合同"; 
$LANG['financial'][98]="末端日期"; 
$LANG['financial'][99]="末端日期+通知"; 
$LANG['financial'][100]="邮政编码"; 
$LANG['financial'][101]="城市"; 
$LANG['financial'][102]="省 / 洲"; 
$LANG['financial'][103]="国家"; 
$LANG['financial'][104]="同项目联系在一起"; 
$LANG['financial'][105]="心照不宣"; 
$LANG['financial'][106]="表达"; 
$LANG['financial'][107]="更新"; 
$LANG['financial'][108]="预算上的花费"; 
$LANG['financial'][109]="预算上总剩余的"; 
$LANG['financial'][110]="预算"; 

$LANG['gmt'][0]="格林尼治标准时间"; 
$LANG['gmt'][1]="小时"; 
$LANG['gmt'][2]="小时"; 

$LANG['help'][1]="微积分的优先矩阵"; 
$LANG['help'][2]="主要"; 
$LANG['help'][3]="非常高"; 
$LANG['help'][4]="高"; 
$LANG['help'][5]="中"; 
$LANG['help'][6]="低"; 
$LANG['help'][7]="非常低"; 
$LANG['help'][8]="通知我关于采取的行动"; 
$LANG['help'][11]="我的邮件地址"; 
$LANG['help'][14]="发送消息"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Your message has been sent successfully, your request is on file."; 
$LANG['help'][19]="Thank you for using our automatic helpdesk system."; 
$LANG['help'][22]="检索您的计算机ID"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="硬件类型"; 
$LANG['help'][25]="计算机"; 
$LANG['help'][26]="网络设备"; 
$LANG['help'][27]="打印机"; 
$LANG['help'][28]="显示器"; 
$LANG['help'][29]="设备"; 
$LANG['help'][30]="通用"; 
$LANG['help'][31]="软件"; 
$LANG['help'][35]="Phone"; 
$LANG['help'][40]="你的标签中没有标题，请重试"; 
$LANG['help'][41]="没有分类在你的标签中，请重试"; 
$LANG['help'][42]="非常高"; 
$LANG['help'][43]="高级的"; 
$LANG['help'][44]="中"; 
$LANG['help'][45]="底级的"; 
$LANG['help'][46]="很低"; 
$LANG['help'][47]="非常高"; 
$LANG['help'][48]="高级的"; 
$LANG['help'][49]="中"; 
$LANG['help'][50]="低级的"; 
$LANG['help'][51]="很低"; 

$LANG['install'][0]="GLPI设施或更新"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="设施"; 
$LANG['install'][4]="更新"; 
$LANG['install'][5]="检查您的环境的兼容性以GLPI的施行"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="发生"; 
$LANG['install'][8]="测试PHP分析器"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI 不兼容zend此项。"; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="会议测试"; 
$LANG['install'][13]="您的PHP分析器没有在会议的支持下被编写!"; 
$LANG['install'][14]="会议的支持是可利用的-完善!"; 
$LANG['install'][15]="检查会议的支持在您的php.ini很好被激活"; 
$LANG['install'][16]="为转储文件检查书写许可"; 
$LANG['install'][17]="文件不可能被创建。"; 
$LANG['install'][18]="非官方的翻译也可"; 
$LANG['install'][19]="文件被创建了但不可能被删除。"; 
$LANG['install'][20]="A file and a directory have be created and deleted - Perfect !"; 
$LANG['install'][21]="为这个文件查检书写权限"; 
$LANG['install'][22]="文件创建成功-本项检测通过"; 
$LANG['install'][23]="为设置文件查检书写许可"; 
$LANG['install'][24]="数据库初始化"; 
$LANG['install'][25]="继续？"; 
$LANG['install'][26]="继续"; 
$LANG['install'][27]="再试"; 
$LANG['install'][28]="数据库连接设定了"; 
$LANG['install'][29]="数据库连接参量"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="连接的测试在数据库"; 
$LANG['install'][35]="不可能连接在数据库"; 
$LANG['install'][36]="服务器应答"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="请选项一个数据库："; 
$LANG['install'][39]="Create a new database or use an existing one:"; 
$LANG['install'][40]="请选项数据库更新："; 
$LANG['install'][41]="不可能使用数据库："; 
$LANG['install'][43]="好-数据库初始化了"; 
$LANG['install'][47]="不可能写数据库设定了文件"; 
$LANG['install'][48]="错误在创建数据库!"; 
$LANG['install'][49]="您没有删除一个数据库!"; 
$LANG['install'][50]="为会议文件查检书写许可"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="检查日志文件的书写权限"; 
$LANG['install'][55]="设施完成"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="GLPI/GLPI为管理员帐户"; 
$LANG['install'][59]="tech/tech为工程师帐户"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="使用GLPI"; 
$LANG['install'][65]="magic_quotes_sybase扩展名测试"; 
$LANG['install'][66]="GLPI不与magic_quotes_sybase选项一起使用; 请设置它再试"; 
$LANG['install'][67]="magic_quotes_sybase选项不是活跃的在您的服务器-完善!"; 
$LANG['install'][68]="任务程序开始自动测试"; 
$LANG['install'][69]="对话auto_star 被激活。在GLPI 浏览htaccess文件以获取更多信息"; 
$LANG['install'][70]="不可能创建数据库连接文件，在文件请验证权限"; 
$LANG['install'][71]="Mysql扩展名测试。"; 
$LANG['install'][72]="您必须编写您的php以Mysql扩展名。"; 
$LANG['install'][73]="好-mysql_query ()功能存在-完美!"; 
$LANG['install'][74]="测试是否使用Session_use_trans_sid"; 
$LANG['install'][75]="你必须处理Session_use_trans_id选项在你的php.ini中"; 
$LANG['install'][76]="好-通用任务程序运行（与trans_id) -完美!"; 
$LANG['install'][77]="步"; 
$LANG['install'][81]="设施的起点"; 
$LANG['install'][82]="Database created"; 
$LANG['install'][85]="作用被发现了-完善!"; 
$LANG['install'][86]="分配了内存测试"; 
$LANG['install'][87]="分配了内存："; 
$LANG['install'][88]="A minimum of 64MB is commonly required for GLPI."; 
$LANG['install'][89]="完善!"; 
$LANG['install'][90]="添加memory_limit参量的尝试在php.ini文件。"; 
$LANG['install'][91]="Allocated memory > 64M"; 
$LANG['install'][92]="使用许可"; 
$LANG['install'][93]="我已阅读并且接受以上所写条款"; 
$LANG['install'][94]="我已阅读但是不接受使用许可上所写的条款"; 
$LANG['install'][95]="内存无限"; 
$LANG['install'][96]="内存无限"; 
$LANG['install'][97]="检查目录的权限"; 
$LANG['install'][99]="检查缓存文件书写的权限"; 
$LANG['install'][100]="这个目录不能被创造。"; 
$LANG['install'][101]="该目录已创建，但不能被删除。"; 
$LANG['install'][102]="测试  json 功能"; 
$LANG['install'][103]="没有编码和译码功能GLPI不能正确工作。"; 
$LANG['install'][104]="mbstring  扩展名测试"; 
$LANG['install'][105]="Mbstring解析器没有安装PHP扩展"; 
$LANG['install'][106]="检查图形文件书写的权限"; 

$LANG['job'][2]="由"; 
$LANG['job'][4]="请求者"; 
$LANG['job'][5]="分配到"; 
$LANG['job'][6]="技术员"; 
$LANG['job'][7]="任务"; 
$LANG['job'][8]="最后标签"; 
$LANG['job'][9]="后续"; 
$LANG['job'][11]="Describe the Problem/Action"; 
$LANG['job'][12]="没有后续的标签"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="解决的"; 
$LANG['job'][19]="邮件后续"; 
$LANG['job'][20]="总期间"; 
$LANG['job'][21]="小时"; 
$LANG['job'][22]="分"; 
$LANG['job'][29]="添加一个新后续"; 
$LANG['job'][30]="添加新的任务"; 
$LANG['job'][31]="期间"; 
$LANG['job'][32]="无"; 
$LANG['job'][33]="空的描述"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="计划"; 
$LANG['job'][37]="总结"; 
$LANG['job'][38]="标签"; 
$LANG['job'][39]="更新后续"; 
$LANG['job'][40]="时间成本"; 
$LANG['job'][41]="固定成本"; 
$LANG['job'][42]="物质费用"; 
$LANG['job'][43]="总成本"; 
$LANG['job'][44]="请求来源"; 
$LANG['job'][45]="后续来源"; 
$LANG['job'][46]="标签将会增加到实体中"; 
$LANG['job'][47]="花费"; 
$LANG['job'][48]="类型的解决方案"; 
$LANG['job'][49]="新的任务"; 
$LANG['job'][50]="没有这一标签任务"; 
$LANG['job'][51]="批准的解决方案"; 
$LANG['job'][52]="更新任务"; 
$LANG['job'][53]="删除任务"; 
$LANG['job'][54]="没有答复，随后标签将会自动关闭"; 

$LANG['joblist'][0]="状态"; 
$LANG['joblist'][1]="只是我的"; 
$LANG['joblist'][2]="优先权"; 
$LANG['joblist'][3]="个人+组"; 
$LANG['joblist'][4]="分配到"; 
$LANG['joblist'][6]="描述"; 
$LANG['joblist'][7]="为这个项目加入新标签"; 
$LANG['joblist'][8]="没有标签被发现"; 
$LANG['joblist'][9]="新的"; 
$LANG['joblist'][10]="关闭了(已解决)"; 
$LANG['joblist'][11]="开始在"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="标签被处理"; 
$LANG['joblist'][14]="关于解决"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="关闭了(没解决)"; 
$LANG['joblist'][18]="处理中(已分配)"; 
$LANG['joblist'][19]="处理中(已计划)"; 
$LANG['joblist'][21]="处理"; 
$LANG['joblist'][26]="待解决"; 
$LANG['joblist'][27]="邮件为后续"; 
$LANG['joblist'][28]="在连接项的标签"; 
$LANG['joblist'][29]="紧急"; 
$LANG['joblist'][30]="冲突"; 
$LANG['joblist'][32]="解决的"; 
$LANG['joblist'][33]="关闭的"; 
$LANG['joblist'][34]="没有解决"; 
$LANG['joblist'][35]="没有关闭"; 
$LANG['joblist'][36]="在数据库中的状态值"; 

$LANG['jobresolution'][1]="解决方案"; 
$LANG['jobresolution'][3]="核定的解决方案"; 
$LANG['jobresolution'][4]="拒绝解决方案"; 
$LANG['jobresolution'][5]="如果你拒绝解决，你必须指出原因"; 

$LANG['knowbase'][1]="常见问题解答"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="为项目选项一个类别："; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="编辑项目"; 
$LANG['knowbase'][9]="删除项目"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="根"; 
$LANG['knowbase'][13]="类别名称"; 
$LANG['knowbase'][14]="主题；主体"; 
$LANG['knowbase'][15]="目录"; 
$LANG['knowbase'][24]="Access to the Frequently Asked Questions"; 
$LANG['knowbase'][26]="观看"; 
$LANG['knowbase'][27]="在"; 
$LANG['knowbase'][29]="最近的项目"; 
$LANG['knowbase'][30]="最热门问题"; 

$LANG['ldap'][0]="从LDAP目录中引入重要的用户"; 
$LANG['ldap'][1]="同步已导入的用户"; 
$LANG['ldap'][2]="引入新的用户"; 
$LANG['ldap'][3]="没有用户需引入"; 
$LANG['ldap'][4]="LDAP 目录选择"; 
$LANG['ldap'][5]="请选择LDAP目录导入用户从"; 
$LANG['ldap'][6]="不能连接到LDAP目录"; 
$LANG['ldap'][7]="LDAP目录中没有定义GLPI"; 
$LANG['ldap'][8]="警告：请求超过了目录的限制。结果只是局部的。"; 
$LANG['ldap'][9]="连接测试到LDAP目录"; 
$LANG['ldap'][12]="同步"; 
$LANG['ldap'][13]="在LDAP目录中"; 
$LANG['ldap'][14]="在GLPI"; 
$LANG['ldap'][15]="同步"; 
$LANG['ldap'][16]="预置"; 
$LANG['ldap'][17]="活动目录"; 
$LANG['ldap'][18]="复制LDAP目录列表"; 
$LANG['ldap'][19]="复制"; 
$LANG['ldap'][20]="增加一个LDAP目录复制品"; 
$LANG['ldap'][21]="主服务器"; 
$LANG['ldap'][22]="复制"; 
$LANG['ldap'][23]="LDAP目录中大量的重要的用户组"; 
$LANG['ldap'][24]="引入新的组"; 
$LANG['ldap'][25]="没有用户组被引入"; 
$LANG['ldap'][30]="LDAP的别名应如何处理"; 
$LANG['ldap'][31]="从来没有解除引用（默认）"; 
$LANG['ldap'][32]="总是取消引用"; 
$LANG['ldap'][33]="在搜查过程（而不是什么时候找出）"; 
$LANG['ldap'][34]="解除引用时定位（不再搜索过程中）"; 
$LANG['ldap'][35]="引入一个用户"; 
$LANG['ldap'][36]="无关联的实体目录：不可能搜索"; 
$LANG['ldap'][38]="用户搜索条件"; 
$LANG['ldap'][39]="高级"; 
$LANG['ldap'][40]="简单的"; 
$LANG['ldap'][41]="要更改"; 
$LANG['ldap'][42]="没有目录选择"; 
$LANG['ldap'][43]="没有用户需要同步"; 
$LANG['ldap'][44]="默认服务器"; 
$LANG['ldap'][45]="一个用户方式在LDAP目录上被删除"; 
$LANG['ldap'][46]="撤销认证和组（动态）"; 
$LANG['ldap'][47]="放入回收站"; 
$LANG['ldap'][48]="在LDAP目录中删除用户"; 
$LANG['ldap'][49]="查看用户添加"; 
$LANG['ldap'][50]="查看用户更新"; 
$LANG['ldap'][52]="小于"; 
$LANG['ldap'][53]="大于，不仅仅"; 
$LANG['ldap'][54]="启用日期过滤"; 
$LANG['ldap'][55]="禁用日期过滤"; 
$LANG['ldap'][56]="星期"; 

$LANG['links'][1]="链接或文件名"; 
$LANG['links'][4]="硬件类型联合"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="没有链接定义了"; 
$LANG['links'][9]="文件内容"; 

$LANG['log'][1]="系统"; 
$LANG['log'][16]="计划"; 
$LANG['log'][18]="部件"; 
$LANG['log'][20]="项目添加了"; 
$LANG['log'][21]="更新项目"; 
$LANG['log'][22]="删除项目"; 
$LANG['log'][23]="恢复项目"; 
$LANG['log'][24]="清除项目"; 
$LANG['log'][26]="断开项目"; 
$LANG['log'][27]="项目连接"; 
$LANG['log'][28]="更新部件"; 
$LANG['log'][29]="批准/拒绝的解决方案"; 
$LANG['log'][30]="关联类型"; 
$LANG['log'][31]="删除类型"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="删除链接与项目"; 
$LANG['log'][34]="add a link with a supplier"; 
$LANG['log'][35]="deletion link with supplier"; 
$LANG['log'][40]="IP连接"; 
$LANG['log'][41]="连接发生了故障"; 
$LANG['log'][42]="保留"; 
$LANG['log'][44]="标题"; 
$LANG['log'][45]="成功"; 
$LANG['log'][46]="发生了故障"; 
$LANG['log'][48]="添加用户到组"; 
$LANG['log'][49]="删除组的用户"; 
$LANG['log'][55]="连接"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="用户添加到实体"; 
$LANG['log'][62]="实体中用户的删除"; 
$LANG['log'][64]="修改字段"; 
$LANG['log'][65]="规矩"; 
$LANG['log'][66]="安全性"; 
$LANG['log'][67]="修改的记录"; 
$LANG['log'][70]="增加网络端口"; 
$LANG['log'][71]="增加几个网络端口"; 
$LANG['log'][73]="删除一个网络端口"; 
$LANG['log'][74]="删除几个网络端口"; 
$LANG['log'][75]="网络端口移动"; 
$LANG['log'][77]="联想到一个VLAN的网络端口"; 
$LANG['log'][78]="一个VLAN关联的几个端口"; 
$LANG['log'][79]="从网络端口中把vlan分里出来"; 
$LANG['log'][80]="从多功能网络端口中分离出一个 VLAN"; 
$LANG['log'][82]="加入版本"; 
$LANG['log'][83]="修改的版本"; 
$LANG['log'][84]="版本的删除"; 
$LANG['log'][85]="添加许可证"; 
$LANG['log'][86]="修改许可"; 
$LANG['log'][87]="删除许可"; 
$LANG['log'][88]="加入墨盒"; 
$LANG['log'][89]="加入消耗品"; 
$LANG['log'][90]="删除一个墨盒"; 
$LANG['log'][91]="删除消耗品"; 
$LANG['log'][92]="恢复一个墨盒"; 
$LANG['log'][93]="恢复消耗品"; 
$LANG['log'][94]="墨盒的更新"; 
$LANG['log'][95]="墨盒的安装"; 
$LANG['log'][96]="墨盒的卸载"; 
$LANG['log'][97]="为用户耗材"; 
$LANG['log'][98]="添加新项目"; 
$LANG['log'][99]="修改的项目"; 
$LANG['log'][100]="删除一项"; 

$LANG['login'][0]="上次登录"; 
$LANG['login'][1]="再次登录"; 
$LANG['login'][2]="LDAP目录"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="中科院"; 
$LANG['login'][5]="拒绝访问"; 
$LANG['login'][6]="用户名"; 
$LANG['login'][7]="密码"; 
$LANG['login'][8]="登录或密码为空"; 
$LANG['login'][9]="认证失败"; 
$LANG['login'][10]="身份验证"; 
$LANG['login'][11]="用户无权连接GLPI"; 
$LANG['login'][12]="用户名或密码错误"; 
$LANG['login'][13]="密码为空"; 
$LANG['login'][14]="未知用户"; 
$LANG['login'][15]="未知用户"; 
$LANG['login'][16]="LDAP认证失败"; 
$LANG['login'][18]="GLPI内部数据库"; 
$LANG['login'][20]="您无权访问：帐号已被停用或删除"; 
$LANG['login'][21]="测试IMAP/POP服务器连接"; 
$LANG['login'][22]="测试成功"; 
$LANG['login'][23]="测试失败"; 
$LANG['login'][24]="上次登录日期"; 
$LANG['login'][25]="您无权访问"; 
$LANG['login'][26]="您必须启用浏览器的JavaScript"; 
$LANG['login'][27]="您必须启用cookie来访问此站点"; 
$LANG['login'][30]="变更认证方式"; 
$LANG['login'][31]="LDAP目录认证"; 
$LANG['login'][32]="GLPI数据库认证"; 
$LANG['login'][33]="IMAP/POP服务器认证"; 

$LANG['mailgate'][0]="邮件接收器"; 
$LANG['mailgate'][2]="现在获得邮件标签。"; 
$LANG['mailgate'][3]="有效邮件数量"; 
$LANG['mailgate'][4]="mbstring扩展名没有被发现。警告使用的字符。"; 
$LANG['mailgate'][5]="无效的附件"; 
$LANG['mailgate'][6]="附件太大"; 
$LANG['mailgate'][7]="每个文件接受邮件的最大数量"; 
$LANG['mailgate'][9]="你的电子邮件无法处理.\ n 如果问题仍然存在，请联系管理员"; 
$LANG['mailgate'][10]="邮件被拒绝"; 
$LANG['mailgate'][11]="接收邮件进程"; 
$LANG['mailgate'][12]="不能影响到实体的电子邮件"; 
$LANG['mailgate'][13]="拒绝的原因"; 
$LANG['mailgate'][14]="电子邮件没有被发现。不可能引入。"; 
$LANG['mailgate'][16]="回复"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="=====================================================================]="; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="标签的描述"; 
$LANG['mailing'][10]="新标签的后续"; 
$LANG['mailing'][12]="标签分配到"; 
$LANG['mailing'][14]="更新分类标签"; 
$LANG['mailing'][15]="更新优先级标签"; 
$LANG['mailing'][17]="更新项目标签"; 
$LANG['mailing'][18]="Update the author of the ticket"; 
$LANG['mailing'][19]="新预订"; 
$LANG['mailing'][20]="Update the group of the ticket"; 
$LANG['mailing'][21]="在标签根源改变"; 
$LANG['mailing'][23]="保留修改"; 
$LANG['mailing'][26]="已添加文档"; 
$LANG['mailing'][27]="更新标签状态"; 
$LANG['mailing'][29]="取消保留"; 
$LANG['mailing'][30]="标签更新"; 
$LANG['mailing'][31]="这是检查邮件系统工作的测试邮件"; 
$LANG['mailing'][32]="邮件测试"; 
$LANG['mailing'][33]="墨盒警报"; 
$LANG['mailing'][35]="消费品种类到达报警阈值："; 
$LANG['mailing'][36]="消费品警报"; 
$LANG['mailing'][37]="在通知时间导入的合同："; 
$LANG['mailing'][39]="合同警报"; 
$LANG['mailing'][40]="项目保修结束："; 
$LANG['mailing'][41]="财政信息警报"; 
$LANG['mailing'][42]="每小时成本变化"; 
$LANG['mailing'][43]="固定成本变化"; 
$LANG['mailing'][44]="在材料成本的变化"; 
$LANG['mailing'][45]="改变标签标头"; 
$LANG['mailing'][46]="改变标签描述"; 
$LANG['mailing'][47]="发送邮件出现错误"; 
$LANG['mailing'][48]="开幕日期的变化"; 
$LANG['mailing'][49]="在截止日期内变更"; 
$LANG['mailing'][50]="更改票务接收机"; 
$LANG['mailing'][51]="过期许可"; 
$LANG['mailing'][53]="变化的解决方案"; 
$LANG['mailing'][54]="截至日期"; 
$LANG['mailing'][100]="没有被定义的类别"; 
$LANG['mailing'][101]="邮件后续可用"; 
$LANG['mailing'][102]="邮件后续不可用"; 
$LANG['mailing'][104]="后续期间"; 
$LANG['mailing'][105]="没分配"; 
$LANG['mailing'][107]="没什么"; 
$LANG['mailing'][109]="没有组"; 
$LANG['mailing'][110]="无效邮件"; 
$LANG['mailing'][113]="通知模板"; 
$LANG['mailing'][114]="正文"; 
$LANG['mailing'][115]="电子邮件的主干"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="正文"; 
$LANG['mailing'][118]="电子邮件"; 
$LANG['mailing'][119]="事件"; 
$LANG['mailing'][120]="通知方法"; 
$LANG['mailing'][121]="容器"; 
$LANG['mailing'][122]="任务已完成"; 
$LANG['mailing'][123]="已解决标签"; 
$LANG['mailing'][124]="添加一个新的翻译"; 
$LANG['mailing'][125]="默认翻译"; 
$LANG['mailing'][126]="模块转换"; 
$LANG['mailing'][127]="关闭的标签"; 
$LANG['mailing'][128]="HTML生成的字段留空"; 
$LANG['mailing'][129]="删除一个标签"; 
$LANG['mailing'][130]="从"; 
$LANG['mailing'][131]="容器"; 
$LANG['mailing'][132]="邮件主题"; 
$LANG['mailing'][133]="删除邮件"; 
$LANG['mailing'][134]="更新后续"; 
$LANG['mailing'][135]="后续的删除"; 
$LANG['mailing'][136]="保留过期"; 
$LANG['mailing'][137]="硬件用户"; 
$LANG['mailing'][138]="有效标记列表"; 
$LANG['mailing'][139]="标注"; 
$LANG['mailing'][140]="标记"; 
$LANG['mailing'][141]="后续的"; 
$LANG['mailing'][142]="任务"; 
$LANG['mailing'][143]="查验"; 
$LANG['mailing'][144]="历史的"; 
$LANG['mailing'][145]="标准列表"; 
$LANG['mailing'][146]="单值"; 
$LANG['mailing'][147]="可能值"; 

$LANG['Menu'][0]="计算机"; 
$LANG['Menu'][1]="网络"; 
$LANG['Menu'][2]="打印机"; 
$LANG['Menu'][3]="显示器"; 
$LANG['Menu'][4]="软件"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="报告"; 
$LANG['Menu'][11]="设置"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="统计"; 
$LANG['Menu'][14]="用户"; 
$LANG['Menu'][15]="管理"; 
$LANG['Menu'][16]="设备"; 
$LANG['Menu'][17]="保留"; 
$LANG['Menu'][18]="工具"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="常见问题文本"; 
$LANG['Menu'][21]="墨盒"; 
$LANG['Menu'][22]="联系人"; 
$LANG['Menu'][23]="Suppliers"; 
$LANG['Menu'][24]="财政信息"; 
$LANG['Menu'][25]="合同"; 
$LANG['Menu'][26]="管理"; 
$LANG['Menu'][27]="文档"; 
$LANG['Menu'][28]="状态"; 
$LANG['Menu'][29]="计划"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="消费品"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="打电话"; 
$LANG['Menu'][35]="个人配置"; 
$LANG['Menu'][36]="组"; 
$LANG['Menu'][37]="实体"; 
$LANG['Menu'][38]="存货清单"; 
$LANG['Menu'][39]="接收"; 
$LANG['Menu'][40]="书签"; 
$LANG['Menu'][41]="权限"; 

$LANG['monitors'][14]="话筒"; 
$LANG['monitors'][15]="扬声器"; 
$LANG['monitors'][18]="标志"; 
$LANG['monitors'][19]="次级D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="大小"; 
$LANG['monitors'][32]="数字视频格式"; 
$LANG['monitors'][33]="数据透视表"; 

$LANG['networking'][4]="网络端口"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="网络端口"; 
$LANG['networking'][13]="发现网络端口"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="连接到"; 
$LANG['networking'][19]="添加网络端口…"; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="在。。。。上"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="端口"; 
$LANG['networking'][46]="添加几个端口…"; 
$LANG['networking'][47]="从"; 
$LANG['networking'][48]="到"; 
$LANG['networking'][51]="Network outlet"; 
$LANG['networking'][55]="关联VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="在名单选择机器地址或在下面指定"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="网关"; 
$LANG['networking'][60]="掩码"; 
$LANG['networking'][61]="子网络"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="导入选项"; 
$LANG['ocsconfig'][6]="忽略OCSNG引入"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="排除下列标签（分隔$,不是对所有）"; 
$LANG['ocsconfig'][10]="全局导入"; 
$LANG['ocsconfig'][11]="没有导入"; 
$LANG['ocsconfig'][12]="单位导入"; 
$LANG['ocsconfig'][13]="部件 导入：每件事物被导入‘当作－是’"; 
$LANG['ocsconfig'][14]="全部导入： 导入所有事件除了已被全局处理过的材料"; 
$LANG['ocsconfig'][15]="没有导入：插件将不导入这些元素"; 
$LANG['ocsconfig'][16]="缺省状态"; 
$LANG['ocsconfig'][17]="极限导入对以下标记(分离器$ ，没什么为所有)"; 
$LANG['ocsconfig'][18]="第一步检查副本已经正确的在OCSNG运行"; 
$LANG['ocsconfig'][19]="单元常数引入连续数字"; 
$LANG['ocsconfig'][27]="General informations"; 
$LANG['ocsconfig'][36]="调制解调器"; 
$LANG['ocsconfig'][37]="端口"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="项目数同步通过自动OCSNG方式"; 
$LANG['ocsconfig'][41]="登录库"; 
$LANG['ocsconfig'][43]="OCSNG管理信息"; 
$LANG['ocsconfig'][48]="拆接时的行为"; 
$LANG['ocsconfig'][49]="垃圾"; 
$LANG['ocsconfig'][50]="删除"; 
$LANG['ocsconfig'][52]="自动连接电脑"; 
$LANG['ocsconfig'][53]="激活自动连接"; 
$LANG['ocsconfig'][54]="一台计算机的存在条件"; 
$LANG['ocsconfig'][55]="查找计算机的状态"; 
$LANG['ocsconfig'][56]="空"; 
$LANG['ocsconfig'][57]="等长度编码"; 
$LANG['ocsconfig'][58]="在OCSNG上两台电脑自动连接GLPI。<br>这个选项是登录帐户在手动连接和同步程序之间。"; 
$LANG['ocsconfig'][59]="OCSNG控制台的网络地址"; 

$LANG['ocsng'][0]="OCS固定资产NG"; 
$LANG['ocsng'][1]="已经导入的计算机的同步"; 
$LANG['ocsng'][2]="添加新计算机的导入"; 
$LANG['ocsng'][3]="清洁GLPI和OCSNG间的联系"; 
$LANG['ocsng'][4]="链接添加新OCS计算机到现有的GLPI计算机"; 
$LANG['ocsng'][5]="导入添加新计算机"; 
$LANG['ocsng'][6]="自动更新"; 
$LANG['ocsng'][7]="从OCSNG导入了"; 
$LANG['ocsng'][8]="导入成功"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="更新计算机"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="导入日期在GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="没有被锁域"; 
$LANG['ocsng'][16]="锁了域"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="注意! 导入的数据(参见您的配置)将改写现有数据"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="同步人工转移"; 
$LANG['ocsng'][26]="选择一个OCSNG服务器"; 
$LANG['ocsng'][27]="没有OCSNG服务器定义"; 
$LANG['ocsng'][29]="OCSNG 服务器"; 
$LANG['ocsng'][30]="锁监视器"; 
$LANG['ocsng'][32]="固定设备"; 
$LANG['ocsng'][34]="锁打印机"; 
$LANG['ocsng'][36]="目的文件实体"; 
$LANG['ocsng'][37]="建立预览"; 
$LANG['ocsng'][38]="关闭预览"; 
$LANG['ocsng'][40]="比较规则？"; 
$LANG['ocsng'][41]="手动引入方式"; 
$LANG['ocsng'][42]="无效OCSNG配置（TRACE_DELETED 必须被激活）"; 
$LANG['ocsng'][43]="访问在OCSNG数据库上被拒绝（需要在硬件上书写权限。 需要检验和）"; 
$LANG['ocsng'][44]="访问被OCSNG数据库拒绝（在deleted_equiv表格中删除权限）"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="在OCSNG上删除"; 
$LANG['ocsng'][47]="和一台OCSNG电脑相连接"; 
$LANG['ocsng'][48]="这台电脑的OCSNG标符已改变"; 
$LANG['ocsng'][49]="代理"; 
$LANG['ocsng'][50]="固定IP"; 
$LANG['ocsng'][52]="锁软件"; 
$LANG['ocsng'][54]="软件被OCSNG同步删除"; 
$LANG['ocsng'][55]="卷 锁定"; 
$LANG['ocsng'][56]="Locked component(s)"; 
$LANG['ocsng'][57]="OCSNG 界面"; 

$LANG['pager'][1]="到"; 
$LANG['pager'][2]="从"; 
$LANG['pager'][3]="在"; 
$LANG['pager'][4]="显示"; 
$LANG['pager'][5]="项目"; 

$LANG['peripherals'][18]="品牌"; 
$LANG['peripherals'][31]="全局管理"; 
$LANG['peripherals'][32]="单位管理"; 
$LANG['peripherals'][33]="管理类型"; 

$LANG['phones'][18]="品牌"; 
$LANG['phones'][36]="电源"; 
$LANG['phones'][38]="耳机"; 
$LANG['phones'][39]="扬声器"; 
$LANG['phones'][40]="行数"; 

$LANG['planning'][0]="技术人员的请求已经委派"; 
$LANG['planning'][1]="错误发生在输入日期中， 起始日期晚于结束日期"; 
$LANG['planning'][5]="天"; 
$LANG['planning'][6]="星期"; 
$LANG['planning'][8]="固定资产跟踪"; 
$LANG['planning'][9]="由"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="Webcal://同步"; 
$LANG['planning'][14]="月"; 
$LANG['planning'][15]="您的计划"; 
$LANG['planning'][16]="信息"; 
$LANG['planning'][17]="要做的"; 
$LANG['planning'][18]="已完成的"; 

$LANG['plugins'][0]="插件列表"; 
$LANG['plugins'][2]="安装／没有配置"; 
$LANG['plugins'][3]="安装／没有激活"; 
$LANG['plugins'][4]="错误／去清理"; 
$LANG['plugins'][5]="不存在的功能"; 
$LANG['plugins'][6]="要更新"; 
$LANG['plugins'][7]="没有安装插件"; 
$LANG['plugins'][8]="查看插件目录"; 
$LANG['plugins'][9]="作者"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serial"; 
$LANG['printers'][15]="Parallel"; 
$LANG['printers'][18]="Ports"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="以太网"; 
$LANG['printers'][29]="无线上网"; 
$LANG['printers'][30]="初始页面计数器"; 
$LANG['printers'][31]="打印了页"; 

$LANG['profiles'][0]="共同权力"; 
$LANG['profiles'][1]="实体权利"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="给我的用户组增加一个跟踪描述标签"; 
$LANG['profiles'][5]="创建一张标签"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Show all tickets"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="读"; 
$LANG['profiles'][11]="写"; 
$LANG['profiles'][12]="不能进入"; 
$LANG['profiles'][13]="缺省配置文件"; 
$LANG['profiles'][14]="删除标签"; 
$LANG['profiles'][15]="添加后续到所有标签"; 
$LANG['profiles'][16]="To be in charge of a ticket"; 
$LANG['profiles'][17]="窃取一个标签"; 
$LANG['profiles'][18]="Update a ticket"; 
$LANG['profiles'][19]="Assign a ticket"; 
$LANG['profiles'][20]="View personnal planning"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="个人配置"; 
$LANG['profiles'][23]="保留管理"; 
$LANG['profiles'][24]="更新密码"; 
$LANG['profiles'][26]="显示我的用户组创建的标签"; 
$LANG['profiles'][27]="查看我的用户组硬件"; 
$LANG['profiles'][28]="循环的"; 
$LANG['profiles'][29]="动态的"; 
$LANG['profiles'][30]="查看OCSNG信息"; 
$LANG['profiles'][31]="手动同步OCSNG"; 
$LANG['profiles'][32]="查看赋值标签（个人＋组 关联）"; 
$LANG['profiles'][33]="没有用户创建"; 
$LANG['profiles'][34]="标题"; 
$LANG['profiles'][35]="更新所有后续"; 
$LANG['profiles'][36]="查看我的用户组中的人员表"; 
$LANG['profiles'][37]="默认实体"; 
$LANG['profiles'][38]="可见性"; 
$LANG['profiles'][39]="赋值"; 
$LANG['profiles'][40]="更新"; 
$LANG['profiles'][41]="创造"; 
$LANG['profiles'][42]="关联"; 
$LANG['profiles'][43]="用户认证和同步方法"; 
$LANG['profiles'][44]="改变优先级"; 
$LANG['profiles'][45]="给所有的标签增加一个任务"; 
$LANG['profiles'][46]="编辑所有的任务"; 
$LANG['profiles'][47]="从外部源中添加用户"; 
$LANG['profiles'][48]="创建一个查验请求"; 
$LANG['profiles'][49]="验证一个标签"; 

$LANG['registry'][1]="蜂巢"; 
$LANG['registry'][2]="路径"; 
$LANG['registry'][3]="键／计算结果"; 
$LANG['registry'][4]="注册表项创建"; 
$LANG['registry'][5]="没有发现关键的在注册表中"; 
$LANG['registry'][6]="OCSNG名"; 

$LANG['reminder'][0]="个人笔记"; 
$LANG['reminder'][1]="公开笔记"; 
$LANG['reminder'][6]="添加新笔记"; 
$LANG['reminder'][9]="文本"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="没有标题"; 
$LANG['reminder'][16]="公用记录"; 

$LANG['reports'][0]="选择一个您想要形成的报告"; 
$LANG['reports'][4]="硬件名单根据合同"; 
$LANG['reports'][11]="硬件根据合同"; 
$LANG['reports'][12]="硬件类型"; 
$LANG['reports'][13]="日期"; 
$LANG['reports'][15]="显示报告"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="缺省报告"; 
$LANG['reports'][27]="根据合同"; 
$LANG['reports'][28]="以年计"; 
$LANG['reports'][33]="网络报告"; 
$LANG['reports'][36]="连接的设备"; 
$LANG['reports'][37]="网络点"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="根据地点"; 
$LANG['reports'][41]="By hardware"; 
$LANG['reports'][42]="根据网络点"; 
$LANG['reports'][46]="hardware ports"; 
$LANG['reports'][47]="设备端口"; 
$LANG['reports'][49]="Network report by hardware"; 
$LANG['reports'][51]="根据网络点的网络报告"; 
$LANG['reports'][52]="交换器"; 
$LANG['reports'][54]="根据地点的网络报告"; 
$LANG['reports'][57]="原料单"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="开始日期"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="其他财政信息(使用许可、墨盒，消费品)"; 
$LANG['reports'][64]="解决日期"; 

$LANG['reservation'][1]="预定的设备"; 
$LANG['reservation'][2]="设备暂时不可用"; 
$LANG['reservation'][3]="不可用的"; 
$LANG['reservation'][5]="提供"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="预订"; 
$LANG['reservation'][9]="预订一个项目"; 
$LANG['reservation'][16]="对"; 
$LANG['reservation'][17]="从"; 
$LANG['reservation'][18]="需要的项目已经预订在需要的时间"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="修改批注"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="星期"; 
$LANG['reservation'][29]="天"; 
$LANG['reservation'][30]="计时"; 
$LANG['reservation'][31]="由"; 
$LANG['reservation'][35]="当前的和预定的"; 
$LANG['reservation'][36]="通过预订"; 
$LANG['reservation'][37]="没有预订"; 
$LANG['reservation'][38]="你是否确认想从贷款项中删除此项？"; 
$LANG['reservation'][39]="将会在进程中删除全部已保留品"; 
$LANG['reservation'][40]="材料今天到期"; 

$LANG['rulesengine'][0]="是"; 
$LANG['rulesengine'][1]="不是"; 
$LANG['rulesengine'][2]="包含"; 
$LANG['rulesengine'][3]="不包含"; 
$LANG['rulesengine'][4]="开始"; 
$LANG['rulesengine'][5]="被。。。完成"; 
$LANG['rulesengine'][6]="条件"; 
$LANG['rulesengine'][7]="行动"; 
$LANG['rulesengine'][8]="规则支配"; 
$LANG['rulesengine'][9]="合理运算符"; 
$LANG['rulesengine'][10]="位置"; 
$LANG['rulesengine'][11]="行动类型"; 
$LANG['rulesengine'][12]="域"; 
$LANG['rulesengine'][13]="计算结果"; 
$LANG['rulesengine'][14]="条件"; 
$LANG['rulesengine'][15]="原因"; 
$LANG['rulesengine'][16]="条件"; 
$LANG['rulesengine'][17]="规则"; 
$LANG['rulesengine'][18]="规则分配一台电脑给实体"; 
$LANG['rulesengine'][19]="实体和权利分配规则"; 
$LANG['rulesengine'][20]="适用规则"; 
$LANG['rulesengine'][21]="在用户中适用的规则"; 
$LANG['rulesengine'][22]="分配"; 
$LANG['rulesengine'][23]="本地规则"; 
$LANG['rulesengine'][24]="规则类型"; 
$LANG['rulesengine'][25]="计算机名"; 
$LANG['rulesengine'][26]="规则表达式复选"; 
$LANG['rulesengine'][27]="规则表达式不匹配"; 
$LANG['rulesengine'][28]="签票的业务规则"; 
$LANG['rulesengine'][29]="列表规则"; 
$LANG['rulesengine'][30]="有效的"; 
$LANG['rulesengine'][33]="下拉字典"; 
$LANG['rulesengine'][35]="软件词典"; 
$LANG['rulesengine'][36]="厂商词典"; 
$LANG['rulesengine'][37]="规则分配一类的软件"; 
$LANG['rulesengine'][38]="重新计算"; 
$LANG['rulesengine'][40]="类别"; 
$LANG['rulesengine'][41]="检验"; 
$LANG['rulesengine'][42]="和"; 
$LANG['rulesengine'][43]="或"; 
$LANG['rulesengine'][45]="从标准表达式中赋值计算结果。"; 
$LANG['rulesengine'][46]="给设备IP地址赋值"; 
$LANG['rulesengine'][47]="给设备名和域赋值"; 
$LANG['rulesengine'][48]="赋值设备"; 
$LANG['rulesengine'][49]="给设备MAC地址赋值"; 
$LANG['rulesengine'][50]="计算机模型字典"; 
$LANG['rulesengine'][51]="监测模型字典"; 
$LANG['rulesengine'][52]="电话模型词典"; 
$LANG['rulesengine'][53]="周边模型字典"; 
$LANG['rulesengine'][54]="打印机模型词典"; 
$LANG['rulesengine'][55]="网络模型字典"; 
$LANG['rulesengine'][56]="模型"; 
$LANG['rulesengine'][60]="计算机模型字典"; 
$LANG['rulesengine'][61]="监视器类型字典"; 
$LANG['rulesengine'][62]="电话模型词典"; 
$LANG['rulesengine'][63]="周边类型词典"; 
$LANG['rulesengine'][64]="打印机类型词典"; 
$LANG['rulesengine'][65]="网络设备类型字典"; 
$LANG['rulesengine'][66]="类型"; 
$LANG['rulesengine'][67]="操作系统字典"; 
$LANG['rulesengine'][68]="服务包字典"; 
$LANG['rulesengine'][69]="操作系统版本词典"; 
$LANG['rulesengine'][70]="通过邮件接受去创建一个规则分配的标签"; 
$LANG['rulesengine'][76]="在词典基础上重命名"; 
$LANG['rulesengine'][77]="词典"; 
$LANG['rulesengine'][78]="版本"; 
$LANG['rulesengine'][79]="在正规表达式中增加一个结果"; 
$LANG['rulesengine'][80]="公用词典"; 
$LANG['rulesengine'][81]="规则结果"; 
$LANG['rulesengine'][82]="结果详细数据"; 
$LANG['rulesengine'][83]="这个有可能影响一个规则表达式使用 #0这个字符串的结果"; 
$LANG['rulesengine'][84]="测试规则引擎"; 
$LANG['rulesengine'][85]="规则表达式的结果"; 
$LANG['rulesengine'][86]="当软件被词典删除，软件分类受到影响"; 
$LANG['rulesengine'][87]="软件被GLPI词典删除"; 
$LANG['rulesengine'][90]="工作进展"; 
$LANG['rulesengine'][91]="工作端"; 
$LANG['rulesengine'][92]="在以词典为基础运行重命名之前发出警告"; 
$LANG['rulesengine'][93]="警告！此操作不能把软件放进垃圾箱。<br>务必通知你的用户。"; 
$LANG['rulesengine'][94]="结合"; 
$LANG['rulesengine'][95]="厂家选择"; 
$LANG['rulesengine'][96]="以厂商词典为基础进行重命名"; 
$LANG['rulesengine'][97]="没有部件进行测试"; 
$LANG['rulesengine'][100]="缓存信息"; 
$LANG['rulesengine'][102]="规则名称"; 
$LANG['rulesengine'][103]="缓存中的对象"; 
$LANG['rulesengine'][104]="初始值"; 
$LANG['rulesengine'][105]="修改计算结果"; 
$LANG['rulesengine'][106]="无变化的"; 
$LANG['rulesengine'][107]="无效的"; 
$LANG['rulesengine'][108]="原始的"; 
$LANG['rulesengine'][110]="赋值权限"; 
$LANG['rulesengine'][111]="实体赋值"; 
$LANG['rulesengine'][112]="权限和实体赋值"; 
$LANG['rulesengine'][120]="该引擎停止了选中的第一个规则"; 
$LANG['rulesengine'][121]="该引擎处理所有的规则"; 
$LANG['rulesengine'][122]="该引擎通过了以下一个规则的结果。"; 
$LANG['rulesengine'][130]="LDAP实体"; 
$LANG['rulesengine'][131]="标记实体"; 
$LANG['rulesengine'][132]="要知道进口"; 
$LANG['rulesengine'][133]="域实体"; 
$LANG['rulesengine'][134]="拒绝电子邮件（没有电子邮件回复）"; 
$LANG['rulesengine'][135]="拒绝电子邮件（与电子邮件回复）"; 
$LANG['rulesengine'][138]="LDAP实体"; 
$LANG['rulesengine'][140]="一个加法的条件"; 
$LANG['rulesengine'][142]="不导入电子邮件名单"; 
$LANG['rulesengine'][144]="实体基于用户的个人资料"; 
$LANG['rulesengine'][145]="用户用一个单一的配置文件"; 
$LANG['rulesengine'][146]="用户文件特性"; 
$LANG['rulesengine'][147]="用户具有一个配置文件"; 
$LANG['rulesengine'][148]="已知邮件域"; 
$LANG['rulesengine'][150]="该规则所连接的实体已失效"; 

$LANG['search'][0]="检索"; 
$LANG['search'][1]="所有"; 
$LANG['search'][2]="包含"; 
$LANG['search'][4]="排序"; 
$LANG['search'][8]="开始日期"; 
$LANG['search'][9]="结束日期"; 
$LANG['search'][10]="在"; 
$LANG['search'][11]="浏览项目"; 
$LANG['search'][12]="显示结束日期"; 
$LANG['search'][15]="没有发现项目"; 
$LANG['search'][16]="最少"; 
$LANG['search'][17]="添加检索标准"; 
$LANG['search'][18]="删除检索标准"; 
$LANG['search'][19]="添加全局检索标准"; 
$LANG['search'][20]="添加全局检索标准"; 

$LANG['setup'][0]="下拉列表"; 
$LANG['setup'][2]="Add user..."; 
$LANG['setup'][3]="LDAP电子词典连接"; 
$LANG['setup'][4]="计算机类型"; 
$LANG['setup'][5]="操作系统"; 
$LANG['setup'][6]="个性化"; 
$LANG['setup'][9]="网络界面"; 
$LANG['setup'][10]="以姓氏顺序显示"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="确认口令"; 
$LANG['setup'][21]="错误：这两个密码不一致"; 
$LANG['setup'][35]="兆赫"; 
$LANG['setup'][39]="遵循私人默认的"; 
$LANG['setup'][40]="默认的私人任务"; 
$LANG['setup'][41]="Select Language"; 
$LANG['setup'][42]="网络类型"; 
$LANG['setup'][43]="打印机类型"; 
$LANG['setup'][44]="显示器类型"; 
$LANG['setup'][45]="案件类型"; 
$LANG['setup'][46]="默认结果"; 
$LANG['setup'][47]="默认图表格式"; 
$LANG['setup'][48]="默认标准"; 
$LANG['setup'][62]="选择类别配置"; 
$LANG['setup'][63]="注意，您将删除一个用于一个或更多项目的标题"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="你可以用另外一个替换这个标题下的所有事件"; 
$LANG['setup'][67]="外在认证"; 
$LANG['setup'][69]="设备型号"; 
$LANG['setup'][70]="一般设定"; 
$LANG['setup'][71]="固件"; 
$LANG['setup'][73]="网络点"; 
$LANG['setup'][74]="您不能删除那个地方，因为它有次级"; 
$LANG['setup'][75]="作为子项目"; 
$LANG['setup'][79]="标签的类别"; 
$LANG['setup'][80]="第三方类型"; 
$LANG['setup'][81]="文件标题"; 
$LANG['setup'][82]="联系人类型"; 
$LANG['setup'][83]="项目状态"; 
$LANG['setup'][84]="墨盒类型"; 
$LANG['setup'][85]="合同类型"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="知识基础分类"; 
$LANG['setup'][88]="网络"; 
$LANG['setup'][89]="域"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="计算机模式"; 
$LANG['setup'][92]="消费品种类"; 
$LANG['setup'][93]="硬盘连接"; 
$LANG['setup'][94]="监视器模式"; 
$LANG['setup'][95]="网络模式"; 
$LANG['setup'][96]="打印机模式"; 
$LANG['setup'][97]="外围设备模式"; 
$LANG['setup'][98]="人物分类"; 
$LANG['setup'][99]="门牌"; 
$LANG['setup'][100]="空间数字"; 
$LANG['setup'][101]="最大数字运行方式（在CLI运行）"; 
$LANG['setup'][102]="Log Level"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2 -服务器(没使用的)"; 
$LANG['setup'][105]="3 -重要(成功登录)"; 
$LANG['setup'][106]="4 -通知(添加，删除，跟踪)"; 
$LANG['setup'][107]="5 -完成(所有)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="在主界面中显示新的标签"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="默认语言"; 
$LANG['setup'][114]="优先权颜色"; 
$LANG['setup'][115]="墨盒和消费品计数的默认阈值"; 
$LANG['setup'][116]="自动分配标签给技术人员负责"; 
$LANG['setup'][117]="批准常见问题解答的匿名视图"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="自动地添加一个外在认证来源的用户"; 
$LANG['setup'][125]="... From an external source"; 
$LANG['setup'][126]="自动地添加一个外部来源的用户"; 
$LANG['setup'][127]="自动完成文本字段"; 
$LANG['setup'][128]="数据格式"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="这一方式的天数记录存储"; 
$LANG['setup'][132]="在树的下来列表中显示完成的名字"; 
$LANG['setup'][133]="激活OCSNG方式"; 
$LANG['setup'][134]="OCSNG方式"; 
$LANG['setup'][135]="正常"; 
$LANG['setup'][136]="翻译"; 
$LANG['setup'][137]="调试"; 
$LANG['setup'][138]="使用GLPI在方式下"; 
$LANG['setup'][139]="公共"; 
$LANG['setup'][140]="键入"; 
$LANG['setup'][145]="操作系统"; 
$LANG['setup'][147]="动态显示"; 
$LANG['setup'][148]="步骤的时间"; 
$LANG['setup'][149]="合计小数数字"; 
$LANG['setup'][150]="数字格式"; 
$LANG['setup'][154]="基于"; 
$LANG['setup'][155]="rootdn (非匿名)"; 
$LANG['setup'][156]="通行证(非匿名)"; 
$LANG['setup'][157]="The LDAP extension of your PHP parser isn't installed"; 
$LANG['setup'][158]="不能用LDAP作为连接的外部来源"; 
$LANG['setup'][159]="连接过滤器"; 
$LANG['setup'][162]="IMAP/POP配置"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="Your PHP parser was compiled without the IMAP functions"; 
$LANG['setup'][166]="不可能使用IMAP/POP作为连接的外部来源"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="连接选项"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="端口(optional)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="端口"; 
$LANG['setup'][176]="根目录(任意)"; 
$LANG['setup'][177]="CAS配置"; 
$LANG['setup'][178]="The CURL or DOMXML extension for your PHP parser isn't installed"; 
$LANG['setup'][179]="不可能用CAS作为连接的外部来源"; 
$LANG['setup'][180]="使用TLS"; 
$LANG['setup'][181]="ldap_start_tls不存在"; 
$LANG['setup'][182]="注销备用网址"; 
$LANG['setup'][185]="文件中的日志（SQL,电子邮件，自动方式）"; 
$LANG['setup'][186]="时间域"; 
$LANG['setup'][190]="x509证书"; 
$LANG['setup'][191]="对于x509 电子邮件属性"; 
$LANG['setup'][192]="激活的"; 
$LANG['setup'][193]="在服务器数组中保持该注册"; 
$LANG['setup'][194]="从LDAP中查检附加信息"; 
$LANG['setup'][195]="保持状态"; 
$LANG['setup'][196]="清楚"; 
$LANG['setup'][197]="复制电脑状态"; 
$LANG['setup'][198]="设置状态"; 
$LANG['setup'][199]="从注册域中删除"; 
$LANG['setup'][200]="无限的"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator Email"; 
$LANG['setup'][204]="邮件署名"; 
$LANG['setup'][205]="邮件送到管理员"; 
$LANG['setup'][206]="发送邮件到管理员失败"; 
$LANG['setup'][207]="管理员回复邮件（如果有需要）"; 
$LANG['setup'][217]="PHP邮件功能未知或没有在您的系统中被激活"; 
$LANG['setup'][218]="对SMTP的使用是需要的"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="日程表计划的极限"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="前线技术人员负责此标签"; 
$LANG['setup'][237]="管理员"; 
$LANG['setup'][239]="技术人员负责此标签"; 
$LANG['setup'][240]="通知选项"; 
$LANG['setup'][241]="没有个人标准。 请创建您的个人参量？"; 
$LANG['setup'][242]="警报选项"; 
$LANG['setup'][243]="消费品警报"; 
$LANG['setup'][244]="墨盒警报"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="合同警报"; 
$LANG['setup'][247]="财政信息警报"; 
$LANG['setup'][248]="标签管理下的用户组"; 
$LANG['setup'][249]="请求者用户组"; 
$LANG['setup'][250]="缺省检索域列表"; 
$LANG['setup'][252]="选择显示缺省项目"; 
$LANG['setup'][253]="在用户组中进行过滤搜索"; 
$LANG['setup'][254]="搜索类型"; 
$LANG['setup'][255]="组的属性包含它的用户"; 
$LANG['setup'][256]="在用户中"; 
$LANG['setup'][257]="在创建组中"; 
$LANG['setup'][258]="用户＆用户组"; 
$LANG['setup'][259]="属于用户组"; 
$LANG['setup'][260]="载有其群体的用户属性"; 
$LANG['setup'][261]="用户组DN"; 
$LANG['setup'][262]="使用DN在搜索中"; 
$LANG['setup'][263]="用户搜索过滤器"; 
$LANG['setup'][264]="在过期的许可证上报警"; 
$LANG['setup'][271]="限制监视器管理"; 
$LANG['setup'][272]="限定设备管理"; 
$LANG['setup'][273]="限制电话管理"; 
$LANG['setup'][274]="手动添加"; 
$LANG['setup'][275]="限制打印机管理"; 
$LANG['setup'][280]="自动更新关于电脑的元件"; 
$LANG['setup'][281]="当连接或者更新"; 
$LANG['setup'][282]="当断开"; 
$LANG['setup'][283]="复制"; 
$LANG['setup'][284]="清楚"; 
$LANG['setup'][285]="不能复制"; 
$LANG['setup'][286]="不要删除"; 
$LANG['setup'][300]="检查新版本是否可用"; 
$LANG['setup'][301]="新版本是可用的："; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="您拥有最新的可用版本"; 
$LANG['setup'][304]="Connection failed. If you use a proxy, please configure it."; 
$LANG['setup'][305]="每天"; 
$LANG['setup'][306]="检查升级"; 
$LANG['setup'][307]="从不"; 
$LANG['setup'][308]="每周"; 
$LANG['setup'][309]="每个月"; 
$LANG['setup'][310]="不能连接到的位置"; 
$LANG['setup'][311]="Failed to connect to the proxy server"; 
$LANG['setup'][312]="在网址上没有有效数据"; 
$LANG['setup'][313]="注意：这里没有默认的计算结果"; 
$LANG['setup'][350]="建立标签的链接项目"; 
$LANG['setup'][351]="所有项目"; 
$LANG['setup'][352]="Linkable items to a ticket"; 
$LANG['setup'][360]="自动区域（用＊标记）"; 
$LANG['setup'][400]="代理设置"; 
$LANG['setup'][407]="简化界面的帮助链接"; 
$LANG['setup'][408]="标准界面辅助连接"; 
$LANG['setup'][409]="默认标题当添加一个文档到标签"; 
$LANG['setup'][503]="电话模型"; 
$LANG['setup'][504]="电话类型"; 
$LANG['setup'][505]="电话类型的电源"; 
$LANG['setup'][601]="LDAP值"; 
$LANG['setup'][602]="连接到OCSNG数据库"; 
$LANG['setup'][603]="添加用户"; 
$LANG['setup'][604]="与一个组联合"; 
$LANG['setup'][606]="不能添加。该用户已经存在"; 
$LANG['setup'][607]="转到一个配置文件"; 
$LANG['setup'][608]="软件默认联想到的书签"; 
$LANG['setup'][609]="不能添加。OCSNG 服务器已经存在"; 
$LANG['setup'][610]="票务的强制性标题"; 
$LANG['setup'][611]="强制标签的内容"; 
$LANG['setup'][612]="强制标签的分类"; 
$LANG['setup'][613]="在LDAP目录中增加一个没有受权的用户"; 
$LANG['setup'][614]="不能更新注册。一个用户已经存在"; 
$LANG['setup'][615]="生命循环标签"; 
$LANG['setup'][616]="从\要"; 
$LANG['setup'][620]="连接"; 
$LANG['setup'][621]="为实体搜索过滤器"; 
$LANG['setup'][622]="描述实体的属性"; 
$LANG['setup'][623]="从LDAP词典中引入实体"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="简易邮件传递协议"; 
$LANG['setup'][652]="简易邮件传递协议＋软件说明语言"; 
$LANG['setup'][653]="简易邮件传递协议＋测试语言"; 
$LANG['setup'][660]="邮件服务器"; 
$LANG['setup'][661]="无法配置通知：请让电子邮件监视"; 
$LANG['setup'][703]="常规"; 
$LANG['setup'][704]="通知"; 
$LANG['setup'][707]="警示预订"; 
$LANG['setup'][708]="标签上出现警报一直未被解决"; 
$LANG['setup'][720]="系统消息"; 
$LANG['setup'][721]="关于系统安装和配置的消息"; 
$LANG['setup'][722]="在你的支持请求中去复制／粘贴"; 
$LANG['setup'][731]="公用配置的计算结果"; 
$LANG['setup'][732]="电子邮箱服务的域名"; 
$LANG['setup'][800]="复制Mysql"; 
$LANG['setup'][801]="允许复制该MySQL"; 
$LANG['setup'][802]="数据库"; 
$LANG['setup'][803]="主机和分机间的区别"; 
$LANG['setup'][806]="主机和分机之间的最大延迟（分）"; 
$LANG['setup'][807]="从属不同步。不同的是："; 
$LANG['setup'][808]="从数据库不同步！"; 
$LANG['setup'][809]="MySQL 复制品： 只读"; 
$LANG['setup'][810]="同步MySQL的复制"; 

$LANG['software'][1]="购买版本"; 
$LANG['software'][2]="在使用版本上"; 
$LANG['software'][3]="没有安装许可"; 
$LANG['software'][4]="无限的"; 
$LANG['software'][5]="Versions"; 
$LANG['software'][6]="发行人"; 
$LANG['software'][7]="添加版本号"; 
$LANG['software'][8]="添加一个许可证"; 
$LANG['software'][11]="使用许可"; 
$LANG['software'][17]="安装了软件"; 
$LANG['software'][19]="安装"; 
$LANG['software'][20]="残余"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="更新"; 
$LANG['software'][30]="许可类型"; 
$LANG['software'][32]="失效"; 
$LANG['software'][44]="安装软件"; 
$LANG['software'][45]="卸载软件"; 
$LANG['software'][46]="联想到一个标签"; 
$LANG['software'][47]="合并"; 
$LANG['software'][48]="合并"; 
$LANG['software'][49]="合并之后删除软件"; 
$LANG['software'][50]="分配给该计算机"; 
$LANG['software'][51]="这个数字必须是1到能够产生作用"; 

$LANG['softwarecategories'][2]="未归类软件"; 
$LANG['softwarecategories'][3]="扩展软件没有分类"; 
$LANG['softwarecategories'][4]="扩展软件属于一个类别"; 
$LANG['softwarecategories'][5]="软件分类"; 

$LANG['state'][0]="状态"; 
$LANG['state'][6]="项目类型"; 
$LANG['state'][7]="没有找到项目"; 
$LANG['state'][11]="综合"; 

$LANG['stats'][0]="选择显示的统计"; 
$LANG['stats'][1]="全局"; 
$LANG['stats'][2]="没有项目显示"; 
$LANG['stats'][3]="每个项目"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="平均决议延迟"; 
$LANG['stats'][7]="显示图形"; 
$LANG['stats'][11]="解决的标签的数量"; 
$LANG['stats'][13]="标签的数量"; 
$LANG['stats'][15]="平均决议延迟"; 
$LANG['stats'][16]="工程师名字"; 
$LANG['stats'][20]="用户名"; 
$LANG['stats'][23]="没有可用的统计"; 
$LANG['stats'][25]="标签真正持续时间的平均值"; 
$LANG['stats'][27]="标签真正的持续时间合计"; 
$LANG['stats'][30]="考虑到标签的平均延迟"; 
$LANG['stats'][31]="天"; 
$LANG['stats'][33]="分钟"; 
$LANG['stats'][34]="秒"; 
$LANG['stats'][35]="标签"; 
$LANG['stats'][44]="Supplier Name"; 
$LANG['stats'][45]="由硬件"; 
$LANG['stats'][47]="由标题"; 
$LANG['stats'][48]="(分配)"; 
$LANG['stats'][49]="(后续)"; 

$LANG['title'][5]="知识库"; 
$LANG['title'][6]="网络"; 
$LANG['title'][9]="项目状态"; 
$LANG['title'][10]="标签后续"; 
$LANG['title'][13]="用户信息"; 
$LANG['title'][14]="外在认证来源"; 
$LANG['title'][24]="协助"; 
$LANG['title'][26]="主要"; 
$LANG['title'][27]="连接"; 
$LANG['title'][28]="标签"; 
$LANG['title'][30]="部件"; 
$LANG['title'][33]="外部链接"; 
$LANG['title'][34]="链接"; 
$LANG['title'][37]="记录"; 
$LANG['title'][38]="历史"; 
$LANG['title'][40]="公开和个人笔记"; 
$LANG['title'][42]="重大修改"; 
$LANG['title'][43]="登录"; 

$LANG['tracking'][1]="我的设备"; 
$LANG['tracking'][2]="完全检索"; 
$LANG['tracking'][3]="无效日期。更新作废。"; 
$LANG['tracking'][4]="在你的标签中没有紧急的，请更正。"; 
$LANG['tracking'][8]="No description for your ticket, please retry."; 
$LANG['tracking'][9]="默认标签"; 
$LANG['tracking'][10]="默认邮件接受者"; 
$LANG['tracking'][24]="文件标签"; 
$LANG['tracking'][29]="数字"; 
$LANG['tracking'][30]="新"; 
$LANG['tracking'][31]="处理(被分配)"; 
$LANG['tracking'][32]="处理(计划)"; 
$LANG['tracking'][34]="直接"; 
$LANG['tracking'][35]="书面"; 
$LANG['tracking'][37]="当清洗硬件时在存货清单中保存标签。"; 
$LANG['tracking'][38]="一封邮件被发送出去"; 
$LANG['tracking'][39]="在简化界面中可见的。"; 

$LANG['transfer'][1]="传送"; 
$LANG['transfer'][3]="如果不再使用"; 
$LANG['transfer'][4]="要清空列表的元素以便被转移"; 
$LANG['transfer'][5]="你可以继续增加元素去转移或者现在执行传送。"; 
$LANG['transfer'][6]="在传送项之前考虑留一个备份"; 
$LANG['transfer'][7]="传送项目"; 
$LANG['transfer'][8]="传送方式"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="数据库更新期间的错误"; 
$LANG['update'][91]="注意!"; 
$LANG['update'][92]="您将更新的GLPI数据库名为："; 
$LANG['update'][93]="数据库连接成功"; 
$LANG['update'][94]="更新成功，您的数据库已更新"; 
$LANG['update'][95]="与数据库的连接发生了故障，请验证config_db.php文件中的连接参数设置"; 
$LANG['update'][96]="现在，所有管理员有超级管理权限。 新用户类型也添加了。"; 
$LANG['update'][105]="无法更新!!"; 
$LANG['update'][106]="返回到GLPI"; 
$LANG['update'][107]="您必须现在更新您的数据库内容"; 
$LANG['update'][130]="地点更新"; 
$LANG['update'][131]="新结构是分级的"; 
$LANG['update'][132]="如果您用了一个分隔符，您可以设置它为自动添加新阶层。"; 
$LANG['update'][133]="您也可以指定一个包括所有生成地点的根地点。"; 
$LANG['update'][134]="分隔符"; 
$LANG['update'][135]="根地点"; 
$LANG['update'][136]="这是添加的新阶层，如果完成，请确认"; 
$LANG['update'][137]="添加新阶层"; 
$LANG['update'][138]="实际地点"; 
$LANG['update'][139]="优化表格"; 
$LANG['update'][140]="创建索引"; 
$LANG['update'][141]="更改数据库的架构"; 
$LANG['update'][142]="数据迁移"; 

$LANG['users'][1]="标题"; 
$LANG['users'][2]="类别"; 

$LANG['validation'][0]="批准"; 
$LANG['validation'][1]="发送一个批准请求"; 
$LANG['validation'][2]="状态"; 
$LANG['validation'][3]="请求日期"; 
$LANG['validation'][4]="批准日期"; 
$LANG['validation'][5]="备注请求"; 
$LANG['validation'][6]="备注检验"; 
$LANG['validation'][7]="批准标签"; 
$LANG['validation'][9]="等待批准"; 
$LANG['validation'][10]="拒绝"; 
$LANG['validation'][11]="已接受"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="审批要求发送到"; 
$LANG['validation'][15]="标签等待你的批准"; 
$LANG['validation'][16]="批准时可选"; 
$LANG['validation'][18]="批准请求者"; 
$LANG['validation'][19]="获批准"; 
$LANG['validation'][20]="拒绝批准"; 
$LANG['validation'][21]="验证程序"; 
$LANG['validation'][23]="该被选用户没有有效邮件地址。该请求已经被创造，没有邮件确认。"; 
$LANG['validation'][25]="Global validation status"; 
$LANG['validation'][26]="批准请求"; 
$LANG['validation'][27]="一个验证请求已经被提交"; 
$LANG['validation'][28]="审批要求的状态"; 
$LANG['validation'][29]="如果得不到批准，指定一个理由"; 
$LANG['validation'][30]="取消的审批要求"; 
$LANG['validation'][31]="更新批准请求"; 
$LANG['validation'][32]="一个查验请求答复被执行"; 
$LANG['validation'][33]="标签等待批准"; 
?>